import React, { Component } from 'react';
import { View, ScrollView, Alert } from 'react-native';
import UserEntry from './UserEntry';
import Networking from '../Networking';
import MyButton from './MyButton';

export default class ListScreen extends Component {
  constructor(props) {
    super(props);
    this.state = {
      users: [],
    };
    this.isRefreshing = true;
  }

  componentDidMount() {
    this.isRefreshing = true;
    Networking.fetchAPI('alldata.php', 'GET')
    .then(res => {
      this.setState({
        users: res
      });
    })
    .catch(err => {
      Alert.alert(...err);
    })
  }

  renderList() {
    return this.state.users.map((user, index) => {
      return (
        <UserEntry 
          key={index} 
          id={index}
          user={user} 
          onDeletePress={this.onDeletePress.bind(this)} 
          onInfoPress={this.onInfoPress.bind(this)}
        />
      );
    });
  }

  render() {
    this.isRefreshing = false;
    return (
      <View>
        <View style={{padding: 8, paddingBottom: 0}}>
          <MyButton color='#66cc66' text='Back' textColor='black' alignSelf='stretch' press={this.props.navigation.goBack} />
        </View>
        <View>
          <ScrollView>
            { this.renderList() }
          </ScrollView>
        </View>
      </View>
    );
  }

  onDeletePress(username) {
    if(this.isRefreshing) return;
    Networking.fetchAPI('delete.php', 'POST', {username})
    .then(res => {
      this.componentDidMount();
    })
    .catch(err => {
      Alert.alert(...err);
    });
  }

  onInfoPress(id) {
    if(this.isRefreshing) return;
    const user = this.state.users[id];
    this.props.navigation.navigate('User info', {user});
  }
}
